==> myfaces-tobago-5.7.1-source-release.zip: tobago-5.7.1/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabelBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.component;

import org.apache.myfaces.tobago.component.Visual;

import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;

/**
 * {@link org.apache.myfaces.tobago.internal.taglib.component.LabelTagDeclaration}
 */
public abstract class AbstractUILabelBase
    extends javax.faces.component.UIOutput implements Visual {

  public String getLabel() {
    final Converter converter = getConverter();
    final Object value = getValue();
    if (converter != null) {
      return converter.getAsString(FacesContext.getCurrentInstance(), this, value);
    } else if (value != null) {
      return String.valueOf(value);
    } else {
      return null;
    }
  }

}

==> myfaces-tobago-6.0.0-source-release.zip: tobago-6.0.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabelBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.component;

import org.apache.myfaces.tobago.component.Visual;

import jakarta.faces.context.FacesContext;
import jakarta.faces.convert.Converter;

/**
 * {@link org.apache.myfaces.tobago.internal.taglib.component.LabelTagDeclaration}
 */
public abstract class AbstractUILabelBase
    extends jakarta.faces.component.UIOutput implements Visual {

  public String getLabel() {
    final Converter converter = getConverter();
    final Object value = getValue();
    if (converter != null) {
      return converter.getAsString(FacesContext.getCurrentInstance(), this, value);
    } else if (value != null) {
      return String.valueOf(value);
    } else {
      return null;
    }
  }

}
